@@ -72,7 +72,7 @@ Classes & Functions
 import requests
 import numpy as np
 
-from .proplist import prop2key, prop2abr, abr2prop, abr2key, properties
+from .proplist import prop2key, prop2abr, abr2prop
 from .version import __version__
 
 __license__   = "MIT"
